mediaquery_sizer library

Classes

Sizer
Provides information about the screen that can be used to your liking An instance can be created via a builder in MaterialApp so you can use it globally and have the screen information wherever you want.

Enums

ScreenSize
The different sizes of screen to be able to manage your design according to the size of screen

Extensions

SizerExt on num
It helps to be able to use the sizes by means of screen percentages in an easy way and using only the MediaQuery through the BuildContext but without having to create an instance of MediaQuery or having to use it directly by writing it completely. For example you can use 20.h(context) and you are automatically pointing to MediaQuery.of(context).size.height * 20