aspectRatio static method
It tells you the exact value of the aspectRatio of the screen
Implementation
static double aspectRatio(BuildContext context) {
return MediaQuery.of(context).size.aspectRatio;
}
It tells you the exact value of the aspectRatio of the screen
static double aspectRatio(BuildContext context) {
return MediaQuery.of(context).size.aspectRatio;
}