devicePixelRatio static method
It tells you the exact value of the devicePixelratio of the screen
Implementation
static double devicePixelRatio(BuildContext context) {
return MediaQuery.of(context).devicePixelRatio;
}
It tells you the exact value of the devicePixelratio of the screen
static double devicePixelRatio(BuildContext context) {
return MediaQuery.of(context).devicePixelRatio;
}