h static method
It tells you the exact value of the height of the screen
Implementation
static double h(BuildContext context) {
return MediaQuery.of(context).size.height;
}
It tells you the exact value of the height of the screen
static double h(BuildContext context) {
return MediaQuery.of(context).size.height;
}