isDesktop static method
It tells you if the screen is desktop so you don't have to put the condition
Implementation
static bool isDesktop(BuildContext context) {
return (screenSize(context) == ScreenSize.desktop) ? true : false;
}
It tells you if the screen is desktop so you don't have to put the condition
static bool isDesktop(BuildContext context) {
return (screenSize(context) == ScreenSize.desktop) ? true : false;
}