isMobile static method
It tells you if the screen is mobile so you don't have to put the condition
Implementation
static bool isMobile(BuildContext context) {
return (screenSize(context) == ScreenSize.mobile) ? true : false;
}
It tells you if the screen is mobile so you don't have to put the condition
static bool isMobile(BuildContext context) {
return (screenSize(context) == ScreenSize.mobile) ? true : false;
}