isTablet static method
It tells you if the screen is tablet so you don't have to put the condition
Implementation
static bool isTablet(BuildContext context) {
return (screenSize(context) == ScreenSize.tablet) ? true : false;
}
It tells you if the screen is tablet so you don't have to put the condition
static bool isTablet(BuildContext context) {
return (screenSize(context) == ScreenSize.tablet) ? true : false;
}