w static method
It tells you the exact value of the width of the screen
Implementation
static double w(BuildContext context) {
return MediaQuery.of(context).size.width;
}
It tells you the exact value of the width of the screen
static double w(BuildContext context) {
return MediaQuery.of(context).size.width;
}